@@ -68,7 +68,7 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
     composite_intro_time=0
     tmp_path_composite_intro = None
     max_duration = 0
-    max_real_duration=1 # thoi gian cua 1 video
+    max_real_duration=3 # thoi gian cua 1 video
     is_compilation=False
     audio_compilation_path=None
     cnt_effect_vid=0
@@ -113,6 +113,9 @@ def create_video(list_comp_data, path_video, job_id, mf_server):
         if comp.type == "element":
             comp.set_bg_clip(CompositeVideoClip(arr_composite.copy()))
             arr_composite = [comp.make()]
+            arr_composite_no_intro = [comp.make()]
+            if max_real_duration < 10:
+                max_real_duration = 10
         else:
             compTmp = comp.make()
             #cut tat ca comp nho hon 10s la intro
@@ -341,6 +344,19 @@ class TextComp(Component):
         rs = TextClip(txt= self.text, font = self.font_path.replace("\\","/"), fontsize=self.font_size, color=self.color,
                         bg_color = self.bg_color, size=(int(self.position['width']), int(self.position['height'])+10),
                         stroke_color = self.stroke_color, stroke_width=self.stroke_width)
+        # if self.position['rotation'] != 0:
+        #     tmp_text= os.path.join(get_dir("coolbg_ffmpeg"),str(uuid.uuid4())+"-text.png")
+        #     rs.save_frame(tmp_text)
+        #     im=rs.get_frame(0)
+        #     if rs.mask is not None:
+        #         mask = 255 * rs.mask.get_frame(0)
+        #         im = np.dstack([im, mask]).astype("uint8")
+        #     else:
+        #         im = im.astype("uint8")
+        #     im=Image.fromarray(im)
+        #     rs = ImageClip(np.asarray(im.rotate(-1 * self.position['rotation'])))
+        # with Image.fromarray(rs.get_frame(0).astype("uint8")) as im:
+        #     rs = ImageClip(np.asarray(im))
         return rs
 
 
@@ -356,13 +372,17 @@ class ImageComp(Component):
     def get_clip(self):
         self.image_path = download_file(self.image_url, ext=self.ext)
         im = Image.open(self.image_path)
-
+        if im.mode =="L" or im.mode =="P" or im.mode =="1":
+            formatter = {"PNG": "RGBA", "JPEG": "RGB"}
+            rgbimg = Image.new(formatter.get(im.format, 'RGB'), im.size)
+            rgbimg.paste(im)
+            im = rgbimg
         width, height = im.size
         if width != self.position['width'] or height != self.position['height']:
             im1 = im.resize((self.position['width'], self.position['height']))
             rs = ImageClip(np.asarray(im1))
         else:
-            rs = ImageClip(self.image_path)
+            rs = ImageClip(np.asarray(im))
         if self.isMask:
             rs = mask_color.mask_color(rs, self.maskColor)
         if self.opacity < 1.0:
