@@ -24,6 +24,7 @@ def create_compilation_songs(data, job_id, mf_server):
     file_merg = open(file_merg_path, "a")
     final_clip_path = os.path.join(get_dir('coolbg_ffmpeg'), str(uuid.uuid4()) + '-final.mp3')
     cnt_song=0
+    one_song_path=""
     try:
         for song in arr_songs:
             try:
@@ -31,6 +32,9 @@ def create_compilation_songs(data, job_id, mf_server):
                 song['local']=''
                 if arr_tmp[0] == "youtube":#youtube
                     song['local']=download_audio(arr_tmp[2])
+                if arr_tmp[0] == "gdrive":#gdrive
+                    tmp = song['uri'].replace("gdrive:track:", "")
+                    song['local'] = download_file(tmp, ext="mp3")
                 if arr_tmp[0] == "direct":#direct
                     tmp=song['uri'].replace("direct:track:","")
                     song['local'] = download_file(tmp)
@@ -40,8 +44,11 @@ def create_compilation_songs(data, job_id, mf_server):
                 if arr_tmp[0] == "spotify":  # spotify
                     arr_song_info = requests.get("http://source.automusic.win/spotify/track/get/" + arr_tmp[2], timeout= 180).json()
                     if len(arr_song_info)>0:
-                        song_info=arr_song_info[0]
+                        song_info = arr_song_info[0]
                         song['local'] = download_file(song_info['url_128'])
+                if arr_tmp[0] == "soundcloud":
+                    tmp = song['uri'].replace("soundcloud:track:", "")
+                    song['local'] = download_file(tmp)
                 if arr_tmp[0] == "automusic" and arr_tmp[1] == "source":
                     arr_song_info = requests.get("http://source.automusic.win/config/f-retrieve/"+arr_tmp[2] +
                                                  f"?jobid={job_id}&mfs={urllib.parse.quote_plus(mf_server)}", timeout= 600).json()
@@ -53,8 +60,8 @@ def create_compilation_songs(data, job_id, mf_server):
 
                 #after download song, re-check song
                 try:
-                    audio_test=AudioFileClip(song['local'])
-                    audioduration=audio_test.duration
+                    audio_test = AudioFileClip(song['local'])
+                    audioduration = audio_test.duration
                     audio_test.close()
                     if audioduration < 1:
                         continue
@@ -71,7 +78,7 @@ def create_compilation_songs(data, job_id, mf_server):
                     shutil.copyfile(song['local'], tmp_clip_path)
                     os.remove(song['local'])
                     song['local']=tmp_clip_path
-
+                one_song_path=song['local']
                 file_merg.write("file '%s'\n" % song['local'])
                 cnt_song+=1
             except:
@@ -90,7 +97,7 @@ def create_compilation_songs(data, job_id, mf_server):
                     pass
         else:
             if cnt_song ==1:
-                return arr_songs[0]['local']
+                return one_song_path
     except:
         pass
     if cnt_song == 0:
